Index: trunk/src/org/expeditee/auth/AuthenticatorBrowser.java
===================================================================
--- trunk/src/org/expeditee/auth/AuthenticatorBrowser.java	(revision 1439)
+++ trunk/src/org/expeditee/auth/AuthenticatorBrowser.java	(revision 1440)
@@ -81,5 +81,5 @@
 	
 	private KeyStore keyStore = KeyStore.getInstance(KeystoreType);
-	public static String USER_NOBODY = "${USER.NAME}";
+	public static String USER_NOBODY = "${USER_NAME}";
 		
 	private static final byte[] TRUE = "yes".getBytes();
Index: trunk/src/org/expeditee/settings/UserSettings.java
===================================================================
--- trunk/src/org/expeditee/settings/UserSettings.java	(revision 1439)
+++ trunk/src/org/expeditee/settings/UserSettings.java	(revision 1440)
@@ -43,5 +43,4 @@
 import org.expeditee.setting.IntegerSetting;
 import org.expeditee.setting.ListSetting;
-import org.expeditee.setting.Setting;
 import org.expeditee.setting.StringSetting;
 import org.expeditee.settings.folders.FolderSettings;
@@ -109,7 +108,7 @@
 	public static final IntegerSetting TitlePosition = new IntegerSetting("Position of title item in frame (TODO: find whether this is x-offset or y-offset)", "TitlePosition", 150);
 		
-	public static final StringSetting UserName = new StringSetting("User name", "${USER.NAME}"); // FrameIO.ConvertToValidFramesetName(System.getProperty("user.name"))
-	
-	public static final StringSetting ProfileName = new StringSetting("Profile name", "${USER.NAME}");
+	public static final StringSetting UserName = new StringSetting("User name", "${USER_NAME}"); // FrameIO.ConvertToValidFramesetName(System.getProperty("user.name"))
+	
+	public static final StringSetting ProfileName = new StringSetting("Profile name", "${USER_NAME}");
 		
 	public static final BooleanSetting AntiAlias = new BooleanSetting("Whether anti-aliasing should be enabled", "AntiAlias", false);
@@ -243,29 +242,28 @@
 	}
 	
-	public static void appendDefaultFolders() {
-		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.PUBLIC_PATH);
-		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.TRASH_PATH);
-		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.PROFILE_PATH);
-		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.GROUP_PATH);
-		
+	public static void appendDefaultFolders() {		
 		if (PublicAndPrivateResources) {
+			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.HELP_USERNAME_PRIVATE_PATH);
 			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.HELP_PATH);
-			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.HELP_USERNAME_PRIVATE_PATH);
+			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.MESSAGES_PATH);
+			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.FRAME_USERNAME_PRIVATE_PATH);
 			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.FRAME_PATH);
-			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.FRAME_USERNAME_PRIVATE_PATH);
-			FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.MESSAGES_PATH);
+			
 			if (AuthenticatorBrowser.isAuthenticated()) {
-				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.SHARED_FRAMESETS_PATH);
+				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.CONTACTS_PATH);
 				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.MAIL_PATH);
-				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.CONTACTS_PATH);
+				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.SHARED_FRAMESETS_PATH);				
 			}
-			FolderSettings.FrameDirs.setDefault(FolderSettings.FrameDirs.get());
-			
-			FolderSettings.ImageDirs.addAbsoluteDir(FrameIO.IMAGES_PATH);
+			
+			FolderSettings.ImageDirs.addAbsoluteDir("${CURRENT_FRAMESET}");
 			FolderSettings.ImageDirs.addAbsoluteDir(FrameIO.IMAGES_USERNAME_PRIVATE_PATH);
-			FolderSettings.ImageDirs.setDefault(FolderSettings.ImageDirs.get());
-			
+			FolderSettings.ImageDirs.addAbsoluteDir(FrameIO.IMAGES_PATH);		
+			
+			FolderSettings.AudioDirs.addAbsoluteDir("${CURRENT_FRAMESET}");
 			FolderSettings.AudioDirs.addAbsoluteDir(FrameIO.AUDIO_PATH);
 			FolderSettings.AudioDirs.addAbsoluteDir(FrameIO.AUDIO_USERNAME_PRIVATE_PATH);
+			
+			FolderSettings.FrameDirs.setDefault(FolderSettings.FrameDirs.get());
+			FolderSettings.ImageDirs.setDefault(FolderSettings.ImageDirs.get());
 			FolderSettings.AudioDirs.setDefault(FolderSettings.AudioDirs.get());
 		} else {
@@ -278,12 +276,18 @@
 				FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.CONTACTS_PATH);
 			}
-			FolderSettings.FrameDirs.setDefault(FolderSettings.FrameDirs.get());
 			
 			FolderSettings.ImageDirs.addAbsoluteDir(FrameIO.IMAGES_PATH);
-			FolderSettings.ImageDirs.setDefault(FolderSettings.ImageDirs.get());
 			
 			FolderSettings.AudioDirs.addAbsoluteDir(FrameIO.AUDIO_PATH);
-			FolderSettings.AudioDirs.setDefault(FolderSettings.AudioDirs.get());
-		}
+		}
+		
+		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.PUBLIC_PATH);
+		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.GROUP_PATH);
+		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.PROFILE_PATH);
+		FolderSettings.FrameDirs.addAbsoluteDir(FrameIO.TRASH_PATH);
+		
+		FolderSettings.FrameDirs.setDefault(FolderSettings.FrameDirs.get());
+		FolderSettings.ImageDirs.setDefault(FolderSettings.ImageDirs.get());
+		FolderSettings.AudioDirs.setDefault(FolderSettings.AudioDirs.get());
 	}
 

Index: trunk/src/org/expeditee/gui/management/ProfileManager.java
===================================================================
--- trunk/src/org/expeditee/gui/management/ProfileManager.java	(revision 1439)
+++ trunk/src/org/expeditee/gui/management/ProfileManager.java	(revision 1440)
@@ -28,5 +28,5 @@
 public class ProfileManager {
 
-	private static final String USER_NAME_PATTERN_INTERNAL = "USER.NAME";
+	private static final String USER_NAME_PATTERN_INTERNAL = "USER_NAME";
 	private static final String DEFAULT = UserSettings.DEFAULT_PROFILE_NAME;
 	private static final String[] startPages = { "exploratorysearch", "webbrowser" };
@@ -71,5 +71,5 @@
 				// 2. Copy item from defaultFrame to the current profile frame being
 				// constructed.
 				// 3. Replace instance of ${USER.NAME} with 'profileFor'
 				// 4. Replace settings values of copied items with those specified in
 				// specifiedSettings (if present)
@@ -85,5 +85,5 @@
 					if (item instanceof Text) {
 						String content = item.getText();
-						item.setText(ResourceUtil.substitute(content, ProfileManager.USER_NAME_PATTERN_INTERNAL, profileFor));
+						item.setText(ResourceUtil.substitute(content, ProfileManager.USER_NAME_PATTERN, profileFor));
 					}
 				}
@@ -71,5 +71,5 @@
 				// 2. Copy item from defaultFrame to the current profile frame being
 				// constructed.
-				// 3. Replace instance of ${USER.NAME} with 'profileFor'
+				// 3. Replace instance of ${USER_NAME} with 'profileFor'
 				// 4. Replace settings values of copied items with those specified in
 				// specifiedSettings (if present)